dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/atmel_lcd.h b/include/atmel_lcd.h
index 4aa955b..66436b9 100644
--- a/include/atmel_lcd.h
+++ b/include/atmel_lcd.h
@@ -10,11 +10,11 @@
 #define _ATMEL_LCD_H_
 
 /**
  * struct atmel_lcd_platdata - platform data for Atmel LCDs with driver model
  *
  * @timing_index:	Index of LCD timing to use in device tree node
  */
-struct atmel_lcd_platdata {
+struct atmel_lcd_plat {
 	int timing_index;
 };
@@ -10,11 +10,11 @@
 
 /**
- * struct atmel_lcd_platdata - platform data for Atmel LCDs with driver model
+ * struct atmel_lcd_plat - platform data for Atmel LCDs with driver model
  *
  * @timing_index:	Index of LCD timing to use in device tree node